@@ -3,13 +3,10 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "accountmanager.h"
-#include "account.h"
-#include "networkaccessmanagerfactory.h"
 
 AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
     , m_selected_account(nullptr)
-    , m_qnam(NetworkAccessManagerFactory().create(this))
 {
     QSettings settings;
     loadFromSettings(settings);
@@ -21,7 +18,7 @@ AccountManager::~AccountManager()
     QSettings settings;
     writeToSettings(settings);
 
-    for (auto a : std::as_const(m_accounts)) {
+    for (auto a : m_accounts) {
         delete a;
     }
 
@@ -37,11 +34,9 @@ QVariant AccountManager::data(const QModelIndex &index, int role) const
     auto account = m_accounts.at(index.row());
     switch (role) {
     case Qt::DisplayRole:
-        return account->identity().displayNameHtml();
+        return account->identity().m_display_name;
     case DescriptionRole:
-        return account->identity().account();
-    case InstanceRole:
-        return account->instanceName();
+        return account->identity().m_acct;
     case AccountRole:
         return QVariant::fromValue(m_accounts[index.row()]);
     }
@@ -50,7 +45,6 @@ QVariant AccountManager::data(const QModelIndex &index, int role) const
 
 int AccountManager::rowCount(const QModelIndex &index) const
 {
-    Q_UNUSED(index)
     return m_accounts.size();
 }
 
@@ -60,7 +54,6 @@ QHash<int, QByteArray> AccountManager::roleNames() const
         {Qt::DisplayRole, QByteArrayLiteral("display")},
         {AccountRole, QByteArrayLiteral("account")},
         {DescriptionRole, QByteArrayLiteral("description")},
-        {InstanceRole, QByteArrayLiteral("instance")},
     };
 }
 
@@ -70,9 +63,9 @@ AccountManager &AccountManager::instance()
     return accountManager;
 }
 
-AbstractAccount *AccountManager::createNewAccount(const QString &username, const QString &instanceUri, bool ignoreSslErrors)
+Account *AccountManager::createNewAccount(const QString &username, const QString &instanceUri)
 {
-    return new Account(username, instanceUri, m_qnam, ignoreSslErrors, this);
+    return new Account(username, instanceUri, this);
 }
 
 bool AccountManager::hasAccounts() const
@@ -80,7 +73,7 @@ bool AccountManager::hasAccounts() const
     return m_accounts.size() > 0;
 }
 
-void AccountManager::addAccount(AbstractAccount *account)
+void AccountManager::addAccount(Account *account)
 {
     beginInsertRows(QModelIndex(), m_accounts.size(), m_accounts.size());
     m_accounts.append(account);
@@ -90,8 +83,8 @@ void AccountManager::addAccount(AbstractAccount *account)
     selectAccount(account);
 
     connect(account, &Account::identityChanged, this, &AccountManager::childIdentityChanged);
-    connect(account, &Account::authenticated, this, [this]() {
-        Q_EMIT dataChanged(index(0, 0), index(m_accounts.size() - 1, 0));
+    connect(account, &Account::authenticated, this, [this, account] () {
+        dataChanged(index(0, 0), index(m_accounts.size() - 1, 0));
     });
 
     connect(account, &Account::fetchedTimeline, this, [this, account](QString original_name, QList<std::shared_ptr<Post>> posts) {
@@ -103,36 +96,29 @@ void AccountManager::addAccount(AbstractAccount *account)
     connect(account, &Account::fetchedInstanceMetadata, this, [this, account]() {
         Q_EMIT fetchedInstanceMetadata(account);
     });
-    connect(account, &Account::invalidatedPost, this, [this, account](Post *p) {
+    connect(account, &Account::invalidatedPost, [this, account](Post *p) {
         Q_EMIT invalidatedPost(account, p);
     });
-    connect(account, &Account::notification, this, [this, account](std::shared_ptr<Notification> n) {
+    connect(account, &Account::notification, [this, account](std::shared_ptr<Notification> n) {
         Q_EMIT notification(account, n);
     });
     QSettings settings;
     writeToSettings(settings);
 }
 
-void AccountManager::childIdentityChanged(AbstractAccount *account)
+void AccountManager::childIdentityChanged(Account *account)
 {
     Q_EMIT identityChanged(account);
 }
 
-void AccountManager::removeAccount(AbstractAccount *account)
+void AccountManager::removeAccount(Account *account)
 {
-    const auto index = m_accounts.indexOf(account);
-    beginRemoveRows(QModelIndex(), index, index);
     m_accounts.removeOne(account);
-    endRemoveRows();
-
-    QSettings settings;
-    settings.clear();
-    writeToSettings(settings);
 
     Q_EMIT accountRemoved(account);
 }
 
-void AccountManager::selectAccount(AbstractAccount *account)
+void AccountManager::selectAccount(Account *account)
 {
     if (!m_accounts.contains(account)) {
         qDebug() << "WTF: attempt to select unmanaged account" << account;
@@ -144,28 +130,17 @@ void AccountManager::selectAccount(AbstractAccount *account)
     Q_EMIT accountSelected(account);
 }
 
-AbstractAccount *AccountManager::selectedAccount() const
+Account *AccountManager::selectedAccount()
 {
     return m_selected_account;
 }
 
-int AccountManager::selectedIndex() const
-{
-    for (int i = 0; i < m_accounts.length(); i++) {
-        if (m_selected_account == m_accounts[i]) {
-            return i;
-        }
-    }
-    return -1;
-}
-
 void AccountManager::writeToSettings(QSettings &settings)
 {
     settings.beginGroup("accounts");
 
-    for (auto a : std::as_const(m_accounts)) {
+    for (auto a : m_accounts)
         a->writeToSettings(settings);
-    }
 
     settings.endGroup();
 }
@@ -180,7 +155,7 @@ void AccountManager::loadFromSettings(QSettings &settings)
     for (const auto &child : childGroups) {
         settings.beginGroup(child);
 
-        auto account = new Account(settings, m_qnam);
+        auto account = new Account(settings);
         if (account->haveToken()) {
             addAccount(account);
             qDebug() << "Loaded from settings:" << account;
