@@ -22,19 +22,19 @@
 #ifdef HAVE_KDBUSADDONS
 #include <KDBusService>
 #endif
+#include <KConfig>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KWindowConfig>
-#include <KConfig>
 
 #include "tokodon-version.h"
 
-#include "accountmanager.h"
 #include "account.h"
+#include "accountmanager.h"
 #include "attachmenteditormodel.h"
-#include "timelinemodel.h"
-#include "post.h"
 #include "clipboard.h"
+#include "post.h"
+#include "timelinemodel.h"
 
 #ifdef Q_OS_ANDROID
 Q_DECL_EXPORT
@@ -47,7 +47,7 @@ int main(int argc, char *argv[])
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QApplication app(argc, argv);
     // Default to org.kde.desktop style unless the user forces another style
@@ -57,12 +57,25 @@ int main(int argc, char *argv[])
 #endif
 
 #ifdef Q_OS_WINDOWS
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+
     QApplication::setStyle(QStringLiteral("breeze"));
+    auto font = app.font();
+    font.setPointSize(10);
+    app.setFont(font);
 #endif
 
     QCoreApplication::setOrganizationName("KDE");
 
-    KAboutData about(QStringLiteral("tokodon"), i18n("Tokodon"), QStringLiteral(TOKODON_VERSION_STRING), i18n("Mastodon client"), KAboutLicense::GPL_V3, i18n("© 2021 Carl Schwan, 2021 KDE Community"));
+    KAboutData about(QStringLiteral("tokodon"),
+                     i18n("Tokodon"),
+                     QStringLiteral(TOKODON_VERSION_STRING),
+                     i18n("Mastodon client"),
+                     KAboutLicense::GPL_V3,
+                     i18n("© 2021 Carl Schwan, 2021 KDE Community"));
     about.addAuthor(i18n("Carl Schwan"), QString(), QStringLiteral("carl@carlschwan.eu"));
     about.setOrganizationDomain("kde.org");
 
@@ -92,13 +105,12 @@ int main(int argc, char *argv[])
 
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Client for the decentralized social network: mastodon"));
-    parser.addVersionOption();
 
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
 
-    //Controller::instance().setAboutData(about);
+    // Controller::instance().setAboutData(about);
 
     engine.load(QUrl(QStringLiteral("qrc:/content/ui/main.qml")));
     if (engine.rootObjects().isEmpty()) {
@@ -119,7 +131,7 @@ int main(int argc, char *argv[])
     });
     const auto rootObjects = engine.rootObjects();
     for (auto obj : rootObjects) {
-        auto view = qobject_cast<QQuickWindow*>(obj);
+        auto view = qobject_cast<QQuickWindow *>(obj);
         if (view) {
             KConfig dataResource("data", KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
             KConfigGroup windowGroup(&dataResource, "Window");
