@@ -4,19 +4,38 @@
 
 #pragma once
 
-#include "abstracttimelinemodel.h"
 #include "accountmanager.h"
 #include "post.h"
 #include <QAbstractListModel>
 
-class NotificationModel : public AbstractTimelineModel
+class NotificationModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(QStringList excludeTypes READ excludeTypes WRITE setExcludesTypes NOTIFY excludeTypesChanged)
 
 public:
-    enum ExtraRoles {
-        NewFollowerIdentityRole = AbstractTimelineModel::ExtraRole,
+    enum CustoRoles {
+        AvatarRole = Qt::UserRole + 1,
+        AuthorDisplayNameRole,
+        PublishedAtRole,
+        AuthorIdRole,
+        RelativeTimeRole,
+        SensitiveRole,
+        SpoilerTextRole,
+        MutedRole,
+        PinnedRole,
+        AttachmentsRole,
+        WasRebloggedRole,
+        RebloggedDisplayNameRole,
+        RebloggedIdRole,
+        RebloggedRole,
+        ReblogsCountRole,
+        RepliesCountRole,
+        FavoritedRole,
+        FavoritesCountRole,
+        ThreadModelRole,
+        AccountModelRole,
+        UrlRole,
     };
 
     explicit NotificationModel(QObject *parent = nullptr);
@@ -24,11 +43,13 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
 
-    virtual void fillTimeline(const QUrl &next = {});
+    virtual void fillTimeline(const QString &fromId = QString());
 
-    std::shared_ptr<Notification> internalData(const QModelIndex &index) const;
-    QStringList excludeTypes() const;
-    void setExcludesTypes(const QStringList &excludeTypes);
+    void disallowUpdates()
+    {
+        m_last_fetch = time(nullptr) + 3;
+    }
+    std::shared_ptr<Post> internalData(const QModelIndex &index) const;
 
 public Q_SLOTS:
     void actionReply(const QModelIndex &index);
@@ -39,8 +60,6 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void excludeTypesChanged();
-    void wantReply(AbstractAccount *account, std::shared_ptr<Post> post, const QModelIndex &index);
-    void wantMenu(AbstractAccount *account, std::shared_ptr<Post> post, const QModelIndex &index);
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
@@ -48,12 +67,12 @@ protected:
 
     QString m_timelineName;
     AccountManager *m_manager = nullptr;
-    AbstractAccount *m_account = nullptr;
+    Account *m_account = nullptr;
 
     QList<std::shared_ptr<Notification>> m_notifications;
     bool m_fetching;
+    time_t m_last_fetch;
     QStringList m_excludeTypes;
-    QUrl m_next;
 
 public Q_SLOTS:
     void fetchedNotifications(QList<std::shared_ptr<Notification>> notifications);
