@@ -5,104 +5,85 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QMap>
-#include <qurl.h>
 
 #include "account.h"
 #include "post.h"
 
-static QMap<QString, Attachment::AttachmentType> stringToAttachmentType = {
-    {"image", Attachment::AttachmentType::Image},
-    {"gifv", Attachment::AttachmentType::GifV},
-    {"video", Attachment::AttachmentType::Video},
-};
+static QMap<QString, Attachment::AttachmentType> str_to_att_type = {{"image", Attachment::AttachmentType::Image},
+                                                                    {"gifv", Attachment::AttachmentType::GifV},
+                                                                    {"video", Attachment::AttachmentType::Video}};
 
-Attachment::Attachment(Post *parent, const QJsonObject &obj)
+Attachment::Attachment(Post *parent, QJsonObject &obj)
     : m_parent(parent)
 {
     m_type = Unknown;
-    if (!obj.contains("type")) {
+    if (!obj.contains("type"))
         return;
-    }
 
     m_id = obj["id"].toString();
     m_url = obj["url"].toString();
     m_preview_url = obj["preview_url"].toString();
     m_description = obj["description"].toString();
-    m_blurhash = obj["blurhash"].toString();
 
     // determine type if we can
     auto type = obj["type"].toString();
-    if (stringToAttachmentType.contains(type)) {
-        m_type = stringToAttachmentType[type];
-    }
+    if (str_to_att_type.contains(type))
+        m_type = str_to_att_type[type];
 }
 
-Attachment::~Attachment() = default;
-
-void Attachment::setDescription(const QString &description)
+Attachment::~Attachment()
 {
-    m_description = description;
+}
+
+void Attachment::setDescription(QString desc)
+{
+    m_description = desc;
     m_parent->updateAttachment(this);
 }
 
-static QMap<Post::Visibility, QString> visibilityToString = {
-    {Post::Visibility::Public, "public"},
-    {Post::Visibility::Unlisted, "unlisted"},
-    {Post::Visibility::Private, "private"},
-    {Post::Visibility::Direct, "direct"},
-};
+static QMap<Post::Visibility, QString> vis_to_str = {{Post::Visibility::Public, "public"},
+                                                     {Post::Visibility::Unlisted, "unlisted"},
+                                                     {Post::Visibility::Private, "private"},
+                                                     {Post::Visibility::Direct, "direct"}};
 
-static QMap<QString, Post::Visibility> stringToVisibility = {
-    {"public", Post::Visibility::Public},
-    {"unlisted", Post::Visibility::Unlisted},
-    {"private", Post::Visibility::Private},
-    {"direct", Post::Visibility::Direct},
-};
+static QMap<QString, Post::Visibility> str_to_vis = {{"public", Post::Visibility::Public},
+                                                     {"unlisted", Post::Visibility::Unlisted},
+                                                     {"private", Post::Visibility::Private},
+                                                     {"direct", Post::Visibility::Direct}};
 
-Post::Post(AbstractAccount *parent)
+Post::Post(Account *parent)
     : QObject(parent)
     , m_parent(parent)
 {
-    QString visibilityString = parent->identity().visibility();
-    m_visibility = stringToVisibility[visibilityString];
+    QString vis_str = parent->identity().m_visibility;
+    m_visibility = str_to_vis[vis_str];
 }
 
-Post::Post(AbstractAccount *parent, QJsonObject obj)
+Post::Post(Account *parent, QJsonObject obj)
     : QObject(parent)
     , m_parent(parent)
     , m_visibility(Post::Visibility::Public)
 {
-    const auto account_doc = obj["account"].toObject();
-    const auto acct = account_doc["acct"].toString();
-    const auto reblog_obj = obj["reblog"].toObject();
-
-    m_original_post_id = obj["id"].toString();
+    auto account_doc = obj["account"].toObject();
+    auto acct = account_doc["acct"].toString();
+    auto reblog_obj = obj["reblog"].toObject();
 
     if (!obj.contains("reblog") || reblog_obj.isEmpty()) {
         m_repeat = false;
-        m_authorIdentity = m_parent->identityLookup(acct, account_doc);
+        m_author_identity = m_parent->identityLookup(acct, account_doc);
     } else {
         m_repeat = true;
 
-        auto repeat_account_doc = reblog_obj["account"].toObject();
+        auto repeat_doc = obj["reblog"].toObject();
+        auto repeat_account_doc = repeat_doc["account"].toObject();
         auto repeat_acct = repeat_account_doc["acct"].toString();
 
-        m_authorIdentity = m_parent->identityLookup(repeat_acct, repeat_account_doc);
-        m_repeatIdentity = m_parent->identityLookup(acct, account_doc);
-
-        obj = reblog_obj;
+        m_author_identity = m_parent->identityLookup(repeat_acct, repeat_account_doc);
+        m_repeat_identity = m_parent->identityLookup(acct, account_doc);
     }
 
     m_subject = obj["spoiler_text"].toString();
     m_content = obj["content"].toString();
-
-    const auto emojis = obj["emojis"].toArray();
-
-    for (const auto &emoji : emojis) {
-        const auto emojiObj = emoji.toObject();
-        m_content = m_content.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'), "<img height=\"16\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
-    }
-
     m_post_id = m_replyTargetId = obj["id"].toString();
     m_isFavorite = obj["favourited"].toBool();
     m_favoriteCount = obj["favourites_count"].toInt();
@@ -112,12 +93,21 @@ Post::Post(AbstractAccount *parent, QJsonObject obj)
     m_isSensitive = obj["sensitive"].toBool();
     m_link = QUrl(obj["url"].toString());
     m_pinned = obj["pinned"].toBool();
-    m_visibility = stringToVisibility[obj["visibility"].toString()];
+    m_visibility = str_to_vis[obj["visibility"].toString()];
     m_published_at = QDateTime::fromString(obj["created_at"].toString(), Qt::ISODate);
-    addAttachments(obj["media_attachments"].toArray());
-    const QJsonArray mentions = obj["mentions"].toArray();
-    if (obj.contains("card") && !obj["card"].toObject().empty()) {
-        setCard(std::make_optional<Card>(obj["card"].toObject()));
+
+    QJsonArray mentions;
+
+    if (m_repeat) {
+        m_visibility = str_to_vis[reblog_obj["visibility"].toString()];
+        m_replyTargetId = reblog_obj["id"].toString();
+        addAttachments(reblog_obj["media_attachments"].toArray());
+
+        mentions = reblog_obj["mentions"].toArray();
+    } else {
+        addAttachments(obj["media_attachments"].toArray());
+
+        mentions = obj["mentions"].toArray();
     }
 
     for (const auto &m : qAsConst(mentions)) {
@@ -130,7 +120,7 @@ Post::Post(AbstractAccount *parent, QJsonObject obj)
 
 Post::~Post()
 {
-    qDeleteAll(m_attachments);
+    m_attachments.clear();
 }
 
 void Post::addAttachments(const QJsonArray &attachments)
@@ -143,18 +133,6 @@ void Post::addAttachments(const QJsonArray &attachments)
     }
 }
 
-void Post::addAttachment(const QJsonObject &attachment)
-{
-    auto att = new Attachment(this, attachment);
-    if (att->m_url.isEmpty()) {
-        return;
-    }
-
-    m_attachments.append(att);
-
-    Q_EMIT attachmentUploaded();
-}
-
 void Post::setInReplyTo(const QString &inReplyTo)
 {
     if (inReplyTo == m_replyTargetId) {
@@ -196,11 +174,10 @@ QJsonDocument Post::toJsonDocument() const
     obj["status"] = m_content;
     obj["content_type"] = m_content_type;
     obj["sensitive"] = m_isSensitive;
-    obj["visibility"] = visibilityToString[m_visibility];
+    obj["visibility"] = vis_to_str[m_visibility];
 
-    if (!m_replyTargetId.isEmpty()) {
+    if (!m_replyTargetId.isEmpty())
         obj["in_reply_to_id"] = m_replyTargetId;
-    }
 
     auto media_ids = QJsonArray();
     for (const auto att : qAsConst(m_attachments)) {
@@ -226,18 +203,16 @@ void Post::updateAttachment(Attachment *a)
     m_parent->updateAttachment(a);
 }
 
-static QMap<QString, Notification::Type> str_to_not_type = {
-    {"favourite", Notification::Type::Favorite},
-    {"follow", Notification::Type::Follow},
-    {"mention", Notification::Type::Mention},
-    {"reblog", Notification::Type::Repeat},
-};
+static QMap<QString, Notification::Type> str_to_not_type = {{"favourite", Notification::Type::Favorite},
+                                                            {"follow", Notification::Type::Follow},
+                                                            {"mention", Notification::Type::Mention},
+                                                            {"reblog", Notification::Type::Repeat}};
 
-Notification::Notification(AbstractAccount *parent, const QJsonObject &obj)
+Notification::Notification(Account *parent, QJsonObject &obj)
     : m_account(parent)
 {
-    const QJsonObject account = obj["account"].toObject();
-    const QJsonObject status = obj["status"].toObject();
+    QJsonObject account = obj["account"].toObject();
+    QJsonObject status = obj["status"].toObject();
     auto acct = account["acct"].toString();
     auto type = obj["type"].toString();
 
@@ -252,26 +227,6 @@ int Notification::id() const
     return m_id;
 }
 
-AbstractAccount *Notification::account() const
-{
-    return m_account;
-}
-
-Notification::Type Notification::type() const
-{
-    return m_type;
-}
-
-std::shared_ptr<Post> Notification::post() const
-{
-    return m_post;
-}
-
-std::shared_ptr<Identity> Notification::identity() const
-{
-    return m_identity;
-}
-
 QString Post::subject() const
 {
     return m_subject;
@@ -341,97 +296,3 @@ void Post::setVisibility(Visibility visibility)
     m_visibility = visibility;
     Q_EMIT visibilityChanged();
 }
-
-std::optional<Card> Post::card() const
-{
-    return m_card;
-}
-
-void Post::setCard(std::optional<Card> card)
-{
-    m_card = card;
-}
-
-Card::Card(QJsonObject card)
-    : m_card(card)
-{
-}
-
-QString Card::authorName() const
-{
-    return m_card[QLatin1String("author_name")].toString();
-}
-
-QString Card::authorUrl() const
-{
-    return m_card[QLatin1String("author_url")].toString();
-}
-
-QString Card::blurhash() const
-{
-    return m_card[QLatin1String("blurhash")].toString();
-}
-
-QString Card::description() const
-{
-    return m_card[QLatin1String("description")].toString();
-}
-
-QString Card::embedUrl() const
-{
-    return m_card[QLatin1String("embed_url")].toString();
-}
-
-int Card::width() const
-{
-    return m_card[QLatin1String("weight")].toInt();
-}
-
-int Card::height() const
-{
-    return m_card[QLatin1String("height")].toInt();
-}
-
-QString Card::html() const
-{
-    return m_card[QLatin1String("html")].toString();
-}
-
-QString Card::image() const
-{
-    return m_card[QLatin1String("image")].toString();
-}
-
-QString Card::providerName() const
-{
-    const auto providerName = m_card[QLatin1String("provider_name")].toString();
-    if (!providerName.isEmpty()) {
-        return providerName;
-    }
-    return url().host();
-}
-
-QString Card::providerUrl() const
-{
-    return m_card[QLatin1String("provider_url")].toString();
-}
-
-QString Card::title() const
-{
-    return m_card[QLatin1String("title")].toString().trimmed();
-}
-
-QUrl Card::url() const
-{
-    return QUrl::fromUserInput(m_card[QLatin1String("url")].toString());
-}
-
-std::shared_ptr<Identity> Post::authorIdentity() const
-{
-    return m_authorIdentity;
-}
-
-std::shared_ptr<Identity> Post::repeatIdentity() const
-{
-    return m_repeatIdentity;
-}
