@@ -3,18 +3,16 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "timelinemodel.h"
-#include "abstractaccount.h"
-#include "abstracttimelinemodel.h"
 #include "accountmodel.h"
-#include "identity.h"
 #include "threadmodel.h"
 #include <KLocalizedString>
 #include <QtMath>
 
 TimelineModel::TimelineModel(QObject *parent)
-    : AbstractTimelineModel(parent)
+    : QAbstractListModel(parent)
     , m_last_fetch(time(nullptr))
 {
+    connect(m_manager, &AccountManager::accountSelected, this, &TimelineModel::nameChanged);
 }
 
 void TimelineModel::setName(const QString &timelineName)
@@ -58,7 +56,7 @@ void TimelineModel::setAccountManager(AccountManager *accountManager)
 
     Q_EMIT accountManagerChanged();
 
-    QObject::connect(m_manager, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+    QObject::connect(m_manager, &AccountManager::accountSelected, this, [=](Account *account) {
         if (m_account == account) {
             return;
         }
@@ -71,7 +69,7 @@ void TimelineModel::setAccountManager(AccountManager *accountManager)
         fillTimeline();
     });
     QObject::connect(m_manager, &AccountManager::fetchedTimeline, this, &TimelineModel::fetchedTimeline);
-    QObject::connect(m_manager, &AccountManager::invalidated, this, [=](AbstractAccount *account) {
+    QObject::connect(m_manager, &AccountManager::invalidated, this, [=](Account *account) {
         if (m_account == account) {
             qDebug() << "Invalidating account" << account;
 
@@ -103,7 +101,6 @@ void TimelineModel::fillTimeline(const QString &from_id)
     }
 
     m_fetching = true;
-    Q_EMIT fetchingChanged();
 
     if (m_account) {
         m_account->fetchTimeline(m_timelineName, from_id);
@@ -119,7 +116,7 @@ void TimelineModel::fetchMore(const QModelIndex &parent)
 
     auto p = m_timeline.last();
 
-    fillTimeline(p->m_original_post_id);
+    fillTimeline(p->m_post_id);
 }
 
 bool TimelineModel::canFetchMore(const QModelIndex &parent) const
@@ -135,13 +132,9 @@ bool TimelineModel::canFetchMore(const QModelIndex &parent) const
     return true;
 }
 
-void TimelineModel::fetchedTimeline(AbstractAccount *account, const QString &original_name, const QList<std::shared_ptr<Post>> &posts)
+void TimelineModel::fetchedTimeline(Account *account, const QString &original_name, const QList<std::shared_ptr<Post>> &posts)
 {
     m_fetching = false;
-    Q_EMIT fetchingChanged();
-
-    m_loading = false;
-    Q_EMIT loadingChanged();
 
     // make sure the timeline update is for us
     if (account != m_account || original_name != m_timelineName) {
@@ -152,6 +145,9 @@ void TimelineModel::fetchedTimeline(AbstractAccount *account, const QString &ori
         return;
     }
 
+    int row = 0;
+    int last = 0;
+
     if (!m_timeline.isEmpty()) {
         const auto post_old = m_timeline.first();
         const auto post_new = posts.first();
@@ -159,22 +155,23 @@ void TimelineModel::fetchedTimeline(AbstractAccount *account, const QString &ori
         qDebug() << "fetchedTimeline"
                  << "post_old->m_post_id" << post_old->m_post_id << "post_new->m_post_id" << post_new->m_post_id;
         if (post_old->m_post_id > post_new->m_post_id) {
-            const int row = m_timeline.size();
-            const int last = row + posts.size() - 1;
-            beginInsertRows(QModelIndex(), row, last);
+            row = m_timeline.size();
+            last = row + posts.size() - 1;
             m_timeline += posts;
-            endInsertRows();
         } else {
-            beginInsertRows(QModelIndex(), 0, posts.size() - 1);
+            row = 0;
+            last = posts.size();
             m_timeline = posts + m_timeline;
-            endInsertRows();
         }
     } else {
-        beginInsertRows(QModelIndex(), 0, posts.size() - 1);
+        row = 0;
+        last = posts.size() - 1;
         m_timeline = posts;
-        endInsertRows();
     }
 
+    beginInsertRows(QModelIndex(), row, last);
+    endInsertRows();
+
     m_last_fetch = time(nullptr);
 }
 
@@ -192,6 +189,35 @@ std::shared_ptr<Post> TimelineModel::internalData(const QModelIndex &index) cons
     return m_timeline[row];
 }
 
+QHash<int, QByteArray> TimelineModel::roleNames() const
+{
+    return {
+        {Qt::DisplayRole, QByteArrayLiteral("display")},
+        {AvatarRole, QByteArrayLiteral("avatar")},
+        {AuthorDisplayNameRole, QByteArrayLiteral("authorDisplayName")},
+        {PinnedRole, QByteArrayLiteral("pinned")},
+        {IdRole, QByteArrayLiteral("id")},
+        {AuthorIdRole, QByteArrayLiteral("authorId")},
+        {PublishedAtRole, QByteArrayLiteral("publishedAt")},
+        {MentionsRole, QByteArrayLiteral("mentions")},
+        {RelativeTimeRole, QByteArrayLiteral("relativeTime")},
+        {SensitiveRole, QByteArrayLiteral("sensitive")},
+        {SpoilerTextRole, QByteArrayLiteral("spoilerText")},
+        {RebloggedRole, QByteArrayLiteral("reblogged")},
+        {WasRebloggedRole, QByteArrayLiteral("wasReblogged")},
+        {RebloggedDisplayNameRole, QByteArrayLiteral("rebloggedDisplayName")},
+        {RebloggedIdRole, QByteArrayLiteral("rebloggedId")},
+        {AttachmentsRole, QByteArrayLiteral("attachments")},
+        {ReblogsCountRole, QByteArrayLiteral("reblogsCount")},
+        {RepliesCountRole, QByteArrayLiteral("repliesCount")},
+        {FavoritedRole, QByteArrayLiteral("favorite")},
+        {FavoritesCountRole, QByteArrayLiteral("favoritesCount")},
+        {UrlRole, QByteArrayLiteral("url")},
+        {ThreadModelRole, QByteArrayLiteral("threadModel")},
+        {AccountModelRole, QByteArrayLiteral("accountModel")},
+    };
+}
+
 QVariant TimelineModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
@@ -201,18 +227,16 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
     auto p = m_timeline[row];
 
     switch (role) {
-    case TypeRole:
-        return false;
     case IdRole:
         return p->m_post_id;
     case Qt::DisplayRole:
         return p->m_content;
     case AvatarRole:
-        return p->authorIdentity()->avatarUrl();
+        return p->m_author_identity->m_avatarUrl;
     case AuthorDisplayNameRole:
-        return p->authorIdentity()->displayNameHtml();
+        return p->m_author_identity->m_display_name;
     case AuthorIdRole:
-        return p->authorIdentity()->account();
+        return p->m_author_identity->m_acct;
     case PublishedAtRole:
         return p->m_published_at;
     case WasRebloggedRole:
@@ -220,13 +244,13 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
     case MentionsRole:
         return p->mentions();
     case RebloggedDisplayNameRole:
-        if (p->repeatIdentity()) {
-            return p->repeatIdentity()->displayNameHtml();
+        if (p->m_repeat_identity) {
+            return p->m_repeat_identity->m_display_name;
         }
         return {};
     case RebloggedIdRole:
-        if (p->repeatIdentity()) {
-            return p->repeatIdentity()->account();
+        if (p->m_repeat_identity) {
+            return p->m_repeat_identity->m_acct;
         }
         return {};
     case RebloggedRole:
@@ -235,8 +259,6 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
         return p->m_repeatedCount;
     case FavoritedRole:
         return p->m_isFavorite;
-    case FavoritesCountRole:
-        return p->m_favoriteCount;
     case PinnedRole:
         return p->m_pinned;
     case SensitiveRole:
@@ -247,31 +269,21 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
         return p->m_subject;
     case AttachmentsRole:
         return QVariant::fromValue<QList<Attachment *>>(p->m_attachments);
-    case CardRole:
-        if (p->card().has_value()) {
-            return QVariant::fromValue<Card>(*p->card());
-        }
-        return false;
     case ThreadModelRole:
         return QVariant::fromValue<QAbstractListModel *>(new ThreadModel(m_manager, p->m_post_id));
     case AccountModelRole:
-        return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_manager, p->authorIdentity()->id(), p->authorIdentity()->account()));
+        return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_manager, p->m_author_identity->m_id, p->m_author_identity->m_acct));
     case RelativeTimeRole: {
         const auto current = QDateTime::currentDateTime();
         auto secsTo = p->m_published_at.secsTo(current);
         if (secsTo < 60 * 60) {
-            const auto hours = p->m_published_at.time().hour();
-            const auto minutes = p->m_published_at.time().minute();
-            return i18nc("hour:minute",
-                         "%1:%2",
-                         hours < 10 ? QChar('0') + QString::number(hours) : QString::number(hours),
-                         minutes < 10 ? QChar('0') + QString::number(minutes) : QString::number(minutes));
+            return i18nc("hour:minute", "%1:%2", p->m_published_at.time().hour(), p->m_published_at.time().minute());
         } else if (secsTo < 60 * 60 * 24) {
             return i18n("%1h", qCeil(secsTo / (60 * 60)));
         } else if (secsTo < 60 * 60 * 24 * 7) {
             return i18n("%1d", qCeil(secsTo / (60 * 60 * 24)));
         }
-        return QLocale::system().toString(p->m_published_at.date(), QLocale::ShortFormat);
+        return p->m_published_at.date().toString(Qt::SystemLocaleShortDate);
     }
     }
 
@@ -335,13 +347,3 @@ void TimelineModel::actionVis(const QModelIndex &index)
 
     Q_EMIT dataChanged(index, index);
 }
-
-void TimelineModel::refresh()
-{
-    fillTimeline();
-}
-
-bool TimelineModel::fetching() const
-{
-    return m_fetching;
-}
