@@ -4,23 +4,48 @@
 
 #pragma once
 
-#include "abstracttimelinemodel.h"
 #include "accountmanager.h"
 #include "post.h"
 #include <QAbstractListModel>
 
-class TimelineModel : public AbstractTimelineModel
+class TimelineModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(AccountManager *accountManager READ accountManager WRITE setAccountManager NOTIFY accountManagerChanged)
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     Q_PROPERTY(QString displayName READ displayName NOTIFY nameChanged)
-    Q_PROPERTY(bool fetching READ fetching NOTIFY fetchingChanged)
 
 public:
+    enum CustoRoles {
+        AvatarRole = Qt::UserRole + 1,
+        IdRole,
+        AuthorDisplayNameRole,
+        PublishedAtRole,
+        AuthorIdRole,
+        RelativeTimeRole,
+        SensitiveRole,
+        SpoilerTextRole,
+        MutedRole,
+        PinnedRole,
+        AttachmentsRole,
+        WasRebloggedRole,
+        RebloggedDisplayNameRole,
+        RebloggedIdRole,
+        RebloggedRole,
+        ReblogsCountRole,
+        MentionsRole,
+        RepliesCountRole,
+        FavoritedRole,
+        FavoritesCountRole,
+        ThreadModelRole,
+        AccountModelRole,
+        UrlRole,
+    };
+
     explicit TimelineModel(QObject *parent = nullptr);
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
     virtual void fillTimeline(const QString &fromId = QString());
 
@@ -38,10 +63,6 @@ public:
     }
     std::shared_ptr<Post> internalData(const QModelIndex &index) const;
 
-    Q_INVOKABLE void refresh();
-
-    bool fetching() const;
-
 public Q_SLOTS:
     void actionReply(const QModelIndex &index);
     void actionFavorite(const QModelIndex &index);
@@ -50,11 +71,10 @@ public Q_SLOTS:
     void actionVis(const QModelIndex &index);
 
 Q_SIGNALS:
-    void wantReply(AbstractAccount *account, std::shared_ptr<Post> post, const QModelIndex &index);
-    void wantMenu(AbstractAccount *account, std::shared_ptr<Post> post, const QModelIndex &index);
+    void wantReply(Account *account, std::shared_ptr<Post> post, const QModelIndex &index);
+    void wantMenu(Account *account, std::shared_ptr<Post> post, const QModelIndex &index);
     void accountManagerChanged();
     void nameChanged();
-    void fetchingChanged();
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
@@ -62,11 +82,12 @@ protected:
 
     QString m_timelineName;
     AccountManager *m_manager = nullptr;
+    Account *m_account = nullptr;
 
     QList<std::shared_ptr<Post>> m_timeline;
     bool m_fetching = false;
     time_t m_last_fetch;
 
 public Q_SLOTS:
-    void fetchedTimeline(AbstractAccount *account, const QString &original_name, const QList<std::shared_ptr<Post>> &posts);
+    void fetchedTimeline(Account *account, const QString &original_name, const QList<std::shared_ptr<Post>> &posts);
 };
